<?php
require_once 'config.php';
require_once 'functions.php';

session_start();
if (!isset($_SESSION['admin'])) {
    header("Location: admin.php");
    exit();
}

$message = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['delete_students']) && !empty($_POST['student_ids'])) {
        $student_ids = $_POST['student_ids'];
        $placeholders = implode(',', array_fill(0, count($student_ids), '?'));
        
        $stmt = $db->prepare("DELETE FROM diakok WHERE id IN ($placeholders)");
        $stmt->bind_param(str_repeat('i', count($student_ids)), ...$student_ids);
        
        if ($stmt->execute()) {
            $message = "A kiválasztott diák(ok) sikeresen törölve!";
        } else {
            $message = "Hiba történt a törlés során.";
        }
    } elseif (isset($_POST['delete_students']) && empty($_POST['student_ids'])) {
        $message = "Nem választottál ki egyetlen diákot sem a törléshez.";
    }
}

$students = $db->query("SELECT id, om_azonosito, nev, osztaly FROM diakok ORDER BY nev");
?>

<!DOCTYPE html>
<html lang="hu">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Diákok Törlése</title>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: 'Roboto', sans-serif;
            line-height: 1.6;
            color: #333;
            max-width: 800px;
            margin: 0 auto;
            padding: 20px;
            background-color: #f0f4f8;
        }
        .logo { text-align: center; margin-bottom: 20px; }
        .logo img { max-width: 200px; height: auto; }
        h1 { color: #2c3e50; text-align: center; }
        table { width: 100%; border-collapse: collapse; margin-bottom: 20px; }
        th, td { border: 1px solid #ddd; padding: 10px; text-align: left; }
        th { background-color: #3498db; color: white; }
        tr:nth-child(even) { background-color: #f2f2f2; }
        input[type="submit"], button { 
            background-color: #e74c3c; 
            color: white; 
            border: none; 
            padding: 10px 20px; 
            cursor: pointer; 
            border-radius: 5px;
            margin-right: 10px;
        }
        input[type="submit"]:hover, button:hover { background-color: #c0392b; }
        .message { 
            background-color: #2ecc71; 
            color: white; 
            padding: 10px; 
            margin-bottom: 20px; 
            border-radius: 5px;
        }
        .back-link {
            display: block;
            text-align: center;
            margin-top: 20px;
            color: #3498db;
            text-decoration: none;
        }
        .controls {
            margin-bottom: 20px;
        }
    </style>
</head>
<body>
    <div class="logo">
        <img src="image/kanizsay.png" alt="Kanizsay logo">
    </div>
    <h1>Diákok Törlése</h1>
    
    <?php if ($message): ?>
        <div class="message"><?= htmlspecialchars($message) ?></div>
    <?php endif; ?>

    <form method="post" id="deleteForm">
        <div class="controls">
            <button type="button" onclick="selectAll()">Összes kijelölése</button>
            <button type="button" onclick="deselectAll()">Összes kijelölés törlése</button>
        </div>
        <table>
            <tr>
                <th>Kiválaszt</th>
                <th>OM Azonosító</th>
                <th>Név</th>
                <th>Osztály</th>
            </tr>
            <?php while ($student = $students->fetch_assoc()): ?>
                <tr>
                    <td><input type="checkbox" name="student_ids[]" value="<?= $student['id'] ?>"></td>
                    <td><?= htmlspecialchars($student['om_azonosito']) ?></td>
                    <td><?= htmlspecialchars($student['nev']) ?></td>
                    <td><?= htmlspecialchars($student['osztaly']) ?></td>
                </tr>
            <?php endwhile; ?>
        </table>
        <input type="submit" name="delete_students" value="Kijelölt diákok törlése" onclick="return confirm('Biztosan törölni szeretnéd a kijelölt diákokat?');">
    </form>

    <a href="admin.php" class="back-link">Vissza az admin felületre</a>

    <script>
        function selectAll() {
            var checkboxes = document.getElementsByName('student_ids[]');
            for (var checkbox of checkboxes) {
                checkbox.checked = true;
            }
        }

        function deselectAll() {
            var checkboxes = document.getElementsByName('student_ids[]');
            for (var checkbox of checkboxes) {
                checkbox.checked = false;
            }
        }
    </script>
</body>
</html>