<?php
require_once 'config.php';
require_once 'functions.php';

session_start();
if (!isset($_SESSION['admin'])) {
    header("Location: admin.php");
    exit();
}

$message = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['delete_requests'])) {
        $request_ids = $_POST['request_ids'];
        $placeholders = implode(',', array_fill(0, count($request_ids), '?'));
        
        $stmt = $db->prepare("DELETE FROM igenyles WHERE id IN ($placeholders)");
        $stmt->bind_param(str_repeat('i', count($request_ids)), ...$request_ids);
        
        if ($stmt->execute()) {
            $message = "A kiválasztott igénylés(ek) sikeresen törölve!";
        } else {
            $message = "Hiba történt a törlés során.";
        }
    }
}

$requests = $db->query("SELECT i.id, d.om_azonosito, d.nev, d.osztaly, i.igenyles_datum, i.statusz 
                        FROM igenyles i 
                        JOIN diakok d ON i.diak_id = d.id 
                        ORDER BY i.igenyles_datum DESC");
?>

<!DOCTYPE html>
<html lang="hu">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Igénylések Törlése</title>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: 'Roboto', sans-serif;
            line-height: 1.6;
            color: #333;
            max-width: 1000px;
            margin: 0 auto;
            padding: 20px;
            background-color: #f0f4f8;
        }
        .logo { text-align: center; margin-bottom: 20px; }
        .logo img { max-width: 200px; height: auto; }
        h1 { color: #2c3e50; text-align: center; }
        table { width: 100%; border-collapse: collapse; margin-bottom: 20px; }
        th, td { border: 1px solid #ddd; padding: 10px; text-align: left; }
        th { background-color: #3498db; color: white; }
        tr:nth-child(even) { background-color: #f2f2f2; }
        input[type="submit"] { 
            background-color: #e74c3c; 
            color: white; 
            border: none; 
            padding: 10px 20px; 
            cursor: pointer; 
            border-radius: 5px;
        }
        input[type="submit"]:hover { background-color: #c0392b; }
        .message { 
            background-color: #2ecc71; 
            color: white; 
            padding: 10px; 
            margin-bottom: 20px; 
            border-radius: 5px;
        }
        .back-link {
            display: block;
            text-align: center;
            margin-top: 20px;
            color: #3498db;
            text-decoration: none;
        }
    </style>
</head>
<body>
    <div class="logo">
        <img src="image/kanizsay.png" alt="Kanizsay logo">
    </div>
    <h1>Igénylések Törlése</h1>
    
    <?php if ($message): ?>
        <div class="message"><?= htmlspecialchars($message) ?></div>
    <?php endif; ?>

    <form method="post">
        <table>
            <tr>
                <th>Kiválaszt</th>
                <th>OM Azonosító</th>
                <th>Név</th>
                <th>Osztály</th>
                <th>Igénylés Dátuma</th>
                <th>Státusz</th>
            </tr>
            <?php while ($request = $requests->fetch_assoc()): ?>
                <tr>
                    <td><input type="checkbox" name="request_ids[]" value="<?= $request['id'] ?>"></td>
                    <td><?= htmlspecialchars($request['om_azonosito']) ?></td>
                    <td><?= htmlspecialchars($request['nev']) ?></td>
                    <td><?= htmlspecialchars($request['osztaly']) ?></td>
                    <td><?= htmlspecialchars($request['igenyles_datum']) ?></td>
                    <td><?= htmlspecialchars($request['statusz']) ?></td>
                </tr>
            <?php endwhile; ?>
        </table>
        <input type="submit" name="delete_requests" value="Kijelölt igénylések törlése">
    </form>

    <a href="admin.php" class="back-link">Vissza az admin felületre</a>
</body>
</html>