<?php
require_once 'config.php';
require_once 'functions.php';
?>

<!DOCTYPE html>
<html lang="hu">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Kártya/Matrica Igénylés</title>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: 'Roboto', sans-serif;
            line-height: 1.6;
            color: #333;
            max-width: 600px;
            margin: 0 auto;
            padding: 20px;
            background-color: #f4f4f4;
        }
        .logo {
            text-align: center;
            margin-bottom: 20px;
        }
        .logo img {
            max-width: 150px;
            height: auto;
        }
        h1, h2 {
            color: #2c3e50;
            text-align: center;
        }
        .section {
            background-color: #fff;
            padding: 20px;
            border-radius: 5px;
            margin-bottom: 20px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        input, button {
            margin: 10px 0;
            padding: 10px;
            width: 100%;
            border: 1px solid #ddd;
            border-radius: 4px;
            box-sizing: border-box;
        }
        button {
            background-color: #3498db;
            color: white;
            border: none;
            cursor: pointer;
            transition: background-color 0.3s ease;
        }
        button:hover {
            background-color: #2980b9;
        }
        #adatok, #uzenet { display: none; }
        @keyframes fadeOut {
            from { opacity: 1; }
            to { opacity: 0; }
        }
        #uzenet {
            animation: fadeOut 1s ease-out 9s forwards;
        }
        .info-box {
            background-color: #e8f6fc;
            border-left: 5px solid #3498db;
            padding: 15px;
            margin-top: 20px;
            border-radius: 5px;
        }
        .important {
            font-weight: bold;
            color: #e74c3c;
        }
        .tipus-valaszto {
            display: flex;
            justify-content: space-between;
            margin: 20px 0;
        }
        .tipus-opcio {
            flex: 1;
            text-align: center;
            padding: 15px;
            border: 2px solid #3498db;
            border-radius: 5px;
            cursor: pointer;
            transition: all 0.3s ease;
        }
        .tipus-opcio:hover {
            background-color: #e8f6fc;
        }
        .tipus-opcio.selected {
            background-color: #3498db;
            color: white;
        }
    </style>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
</head>
<body>
    <div class="logo">
        <img src="image/kanizsay.png" alt="Kanizsay logo">
    </div>
    
    <h1>Kártya/Matrica Igénylés</h1>

    <div class="section">
        <p class="important">Kártya vagy matrica igényléséhez add meg az OKTATÁSI azonosítódat!</p>
        <input type="text" id="omAzonosito" placeholder="OKTATÁSI azonosító (11 számjegy)">
        <button onclick="lekerdezes()">Adatok lekérdezése</button>
        
        <div id="adatok">
            <p>Név: <span id="nev"></span></p>
            <p>Osztály: <span id="osztaly"></span></p>
            <p>Hanyadik kártya igénylése: <span id="kartyaSzam"></span></p>
            <p>Válassz típust:</p>
            <div class="tipus-valaszto">
                <div class="tipus-opcio" data-tipus="kartya">Kártya</div>
                <div class="tipus-opcio" data-tipus="matrica">Matrica</div>
            </div>
            <button onclick="igenyles()">Igénylés</button>
        </div>

        <div id="uzenet"></div>

        <div class="info-box">
            <p><strong>Fontos információ:</strong></p>
            <p>A kártyák és matricák átvétele mindig a következő napon a 12:40-es szünetben lehetséges.<br> A pótdíj összege 1.000 forint. (Átvételkor fizetendő, kártyánként.)<br>A matrica évente egyszer ingyenes, utána 500 forint a pótlása.</p>
        </div>
    </div>

    <script>
        var diakId;
        var selectedTipus;

        function lekerdezes() {
            var omAzonosito = document.getElementById('omAzonosito').value;
            $.ajax({
                url: 'api.php',
                type: 'POST',
                data: JSON.stringify({action: 'lekerdezes', om_azonosito: omAzonosito}),
                contentType: 'application/json',
                dataType: 'json',
                success: function(diakAdatok) {
                    if (diakAdatok) {
                        diakId = diakAdatok.id;
                        document.getElementById('nev').textContent = diakAdatok.nev;
                        document.getElementById('osztaly').textContent = diakAdatok.osztaly;
                        document.getElementById('kartyaSzam').textContent = parseInt(diakAdatok.kartya_szam) + 1;
                        document.getElementById('adatok').style.display = 'block';
                    } else {
                        alert('Nem található diák ezzel az oktatási azonosítóval.');
                    }
                },
                error: function() {
                    alert('Hiba történt az adatok lekérdezése során. Kérjük, próbáld újra később.');
                }
            });
        }

        function igenyles() {
            if (!selectedTipus) {
                alert('Kérlek, válassz típust (kártya vagy matrica)!');
                return;
            }

            $.ajax({
                url: 'api.php',
                type: 'POST',
                data: JSON.stringify({action: 'igenyles', diak_id: diakId, tipus: selectedTipus}),
                contentType: 'application/json',
                dataType: 'json',
                success: function(result) {
                    if (result.success) {
                        var nev = document.getElementById('nev').textContent;
                        var uzenet = 'Kedves ' + nev + '! A ' + selectedTipus + ' igénylése sikeres volt. Amint látod a nevedet a tableten, át is tudod venni.';
                        document.getElementById('uzenet').innerHTML = uzenet;
                        document.getElementById('uzenet').style.display = 'block';
                        document.getElementById('adatok').style.display = 'none';
                        
                        setTimeout(function() {
                            document.getElementById('uzenet').style.display = 'none';
                            document.getElementById('omAzonosito').value = '';
                            selectedTipus = null;
                            $('.tipus-opcio').removeClass('selected');
                        }, 10000);
                    } else {
                        alert('Hiba történt az igénylés során. Kérjük, próbáld újra később.');
                    }
                },
                error: function() {
                    alert('Hiba történt az igénylés során. Kérjük, próbáld újra később.');
                }
            });
        }

        $(document).ready(function() {
            $('.tipus-opcio').click(function() {
                $('.tipus-opcio').removeClass('selected');
                $(this).addClass('selected');
                selectedTipus = $(this).data('tipus');
            });
        });
    </script>
</body>
</html>