<?php
require_once 'config.php';
require_once 'functions.php';

session_start();
if (!isset($_SESSION['admin'])) {
    header('Location: admin.php');
    exit;
}

$uzenet = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $om_azonosito = $_POST['om_azonosito'];
    $nev = $_POST['nev'];
    $osztaly = $_POST['osztaly'];

    if (empty($om_azonosito) || empty($nev) || empty($osztaly)) {
        $uzenet = "Minden mező kitöltése kötelező!";
    } else {
        if (!preg_match('/^\d{11}$/', $om_azonosito)) {
            $uzenet = "Az OM azonosítónak 11 számjegyből kell állnia!";
        } else {
            $stmt = $db->prepare("SELECT id FROM diakok WHERE om_azonosito = ?");
            $stmt->bind_param("s", $om_azonosito);
            $stmt->execute();
            $result = $stmt->get_result();
            
            if ($result->num_rows > 0) {
                $uzenet = "Ez az OM azonosító már létezik az adatbázisban!";
            } else {
                $stmt = $db->prepare("INSERT INTO diakok (om_azonosito, nev, osztaly) VALUES (?, ?, ?)");
                $stmt->bind_param("sss", $om_azonosito, $nev, $osztaly);
                
                if ($stmt->execute()) {
                    $uzenet = "Diák sikeresen felvéve az adatbázisba!";
                } else {
                    $uzenet = "Hiba történt a diák felvétele során: " . $db->error;
                }
            }
        }
    }
}
?>

<!DOCTYPE html>
<html lang="hu">
<head>
    <meta charset="UTF-8">
    <title>Diák felvétele</title>
    <style>
        body { font-family: Arial, sans-serif; max-width: 600px; margin: 0 auto; padding: 20px; }
        form { background-color: #f0f0f0; padding: 20px; border-radius: 5px; }
        input[type="text"], input[type="submit"] { width: 100%; padding: 10px; margin: 5px 0; }
        .uzenet { background-color: #e0e0e0; padding: 10px; margin-top: 20px; border-radius: 5px; }
    </style>
</head>
<body>
    <h1>Diák felvétele az adatbázisba</h1>

    <form method="post">
        <input type="text" name="om_azonosito" placeholder="OM azonosító (11 számjegy)" required>
        <input type="text" name="nev" placeholder="Név" required>
        <input type="text" name="osztaly" placeholder="Osztály" required>
        <input type="submit" value="Diák felvétele">
    </form>

    <?php if ($uzenet): ?>
        <div class="uzenet"><?= htmlspecialchars($uzenet) ?></div>
    <?php endif; ?>

    <p><a href="admin.php">Vissza az admin felületre</a></p>
</body>
</html>