<?php
require_once 'config.php';
require_once 'functions.php';

function getElkeszultIgenyles() {
    global $db;
    $elkeszult_igenyles = $db->query("SELECT d.nev, d.osztaly, i.tipus
                                     FROM igenyles i 
                                     JOIN diakok d ON i.diak_id = d.id 
                                     WHERE i.statusz = 'Elkészült'
                                     ORDER BY d.nev");
    return $elkeszult_igenyles;
}

function getCurrentMessages() {
    global $db;
    return $db->query("SELECT message, is_blinking FROM messages ORDER BY sorrend ASC, created_at DESC");
}

if (isset($_GET['ajax'])) {
    $response = [];
    
    // Elkészült igénylések
    $elkeszult_igenyles = getElkeszultIgenyles();
    $igenyles_html = '';
    if ($elkeszult_igenyles->num_rows > 0) {
        while ($row = $elkeszult_igenyles->fetch_assoc()) {
            $igenyles_html .= '<div class="message">';
            $igenyles_html .= '<p>Kedves ' . htmlspecialchars($row['nev']) . '!</p>';
            $igenyles_html .= '<p>' . ucfirst($row['tipus']) . 'd elkészült és átvehető a NAGY szünetek valamelyikében.</p>';
            $igenyles_html .= '</div>';
        }
    } else {
        $igenyles_html = '<p>Jelenleg nincs átvehető kártya vagy matrica.</p>';
    }
    $response['igenyles'] = $igenyles_html;
    
    // Admin üzenetek
    $current_messages = getCurrentMessages();
    $messages_html = '';
    while ($message = $current_messages->fetch_assoc()) {
        $blinking_class = $message['is_blinking'] ? 'blinking' : '';
        $messages_html .= "<div class='important-message $blinking_class'>" . htmlspecialchars($message['message']) . "</div>";
    }
    $response['admin_messages'] = $messages_html;
    
    echo json_encode($response);
    exit;
}

$elkeszult_igenyles = getElkeszultIgenyles();
$current_messages = getCurrentMessages();
?>

<!DOCTYPE html>
<html lang="hu">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Elkészült Kártyák és Matricák</title>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: 'Roboto', sans-serif;
            line-height: 1.6;
            color: #333;
            max-width: 800px;
            margin: 0 auto;
            padding: 20px;
            background-color: #f4f4f8;
        }
        .header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 30px;
        }
        .logo img, .qr-code img {
            max-width: 150px;
            height: auto;
        }
        .school-name {
            text-align: center;
            font-size: 18px;
            font-weight: bold;
            color: #2c3e50;
            margin: 0 20px;
        }
        .qr-info {
            text-align: center;
            margin-bottom: 20px;
            font-size: 14px;
            color: #555;
        }
        h1 {
            color: #2c3e50;
            text-align: center;
        }
        .section {
            background-color: #fff;
            padding: 25px;
            border-radius: 8px;
            margin-bottom: 30px;
            box-shadow: 0 4px 6px rgba(0,0,0,0.1);
        }
        .message {
            background-color: #e8f6fc;
            padding: 15px;
            border-radius: 5px;
            margin-bottom: 10px;
            border-left: 5px solid #3498db;
        }
        .important-message {
            background-color: #ffcccc;
            border: 2px solid #ff0000;
            color: #ff0000;
            padding: 10px;
            margin-bottom: 10px;
            font-weight: bold;
            text-align: center;
        }
        @keyframes blink {
            0% { opacity: 1; }
            50% { opacity: 0; }
            100% { opacity: 1; }
        }
        .blinking {
            animation: blink 1s linear infinite;
        }
    </style>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
</head>
<body>
    <div class="header">
        <div class="logo">
            <img src="image/kanizsay.png" alt="Kanizsay logo">
        </div>
        <div class="school-name">
            Kanizsay Dorottya Katolikus Középiskola
        </div>
        <div class="qr-code">
            <img src="https://api.qrserver.com/v1/create-qr-code/?size=150x150&data=https://kartyaigeny.kanizsay.edu.hu/kartyaigeny.php" alt="QR kód a kártya igényléshez">
        </div>
    </div>
    
    <div class="qr-info">
        Olvasd be a QR kódot a telefonoddal, és igényelj új kártyát vagy matricát egyszerűen!
    </div>

    <div id="admin-messages-container">
        <?php
        while ($message = $current_messages->fetch_assoc()) {
            $blinking_class = $message['is_blinking'] ? 'blinking' : '';
            echo "<div class='important-message $blinking_class'>" . htmlspecialchars($message['message']) . "</div>";
        }
        ?>
    </div>

    <h1>Elkészült Kártyák és Matricák</h1>

    <div class="section">
        <div id="igenyles-container">
            <?php if ($elkeszult_igenyles->num_rows > 0): ?>
                <?php while ($row = $elkeszult_igenyles->fetch_assoc()): ?>
                    <div class="message">
                        <p>Kedves <?= htmlspecialchars($row['nev']) ?>!</p>
                        <p><?= ucfirst($row['tipus']) ?>d elkészült és átvehető a NAGY szünetek valamelyikében.</p>
                    </div>
                <?php endwhile; ?>
            <?php else: ?>
                <p>Jelenleg nincs átvehető kártya vagy matrica.</p>
            <?php endif; ?>
        </div>
    </div>

    <script>
        function frissitAdatok() {
            $.get('index.php?ajax=1', function(data) {
                var response = JSON.parse(data);
                $('#igenyles-container').html(response.igenyles);
                $('#admin-messages-container').html(response.admin_messages);
            });
        }

        $(document).ready(function() {
            setInterval(frissitAdatok, 10000);
        });
    </script>
</body>
</html>