<?php
require_once 'config.php';
require_once 'functions.php';

session_start();
if (!isset($_SESSION['admin'])) {
    header("Location: admin.php");
    exit();
}

// Összes kártya igénylés listája
$osszes_igenyles = $db->query("SELECT i.id, d.nev, d.osztaly, i.igenyles_datum, i.statusz 
                               FROM igenyles i 
                               JOIN diakok d ON i.diak_id = d.id 
                               ORDER BY i.igenyles_datum DESC");

$statusz_leirasok = [
    'Folyamatban' => 'Igénylés megjött, de még a kártya nincs kész.',
    'Átvéve' => 'A kártya kiadva és kifizetve.',
    'Megtalálta' => 'A kártyát megtalálta, így tárgytalan.',
    'Nem kell' => 'A kártyát újra igényelte anélkül, hogy átvette volna az előzőt.'
];
?>

<!DOCTYPE html>
<html lang="hu">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Összes Kártya Igénylés</title>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: 'Roboto', sans-serif;
            line-height: 1.6;
            color: #333;
            max-width: 1200px;
            margin: 0 auto;
            padding: 20px;
            background-color: #f0f4f8;
        }
        .logo {
            text-align: center;
            margin-bottom: 30px;
        }
        .logo img {
            max-width: 200px;
            height: auto;
        }
        h1, h2 {
            color: #2c3e50;
            text-align: center;
        }
        .section {
            background-color: #fff;
            padding: 25px;
            border-radius: 8px;
            margin-bottom: 30px;
            box-shadow: 0 4px 6px rgba(0,0,0,0.1);
        }
        table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 20px;
        }
        th, td {
            border: 1px solid #ddd;
            padding: 12px;
            text-align: left;
        }
        th {
            background-color: #3498db;
            color: white;
        }
        tr:nth-child(even) {
            background-color: #f8f9fa;
        }
        .back-link {
            display: block;
            text-align: center;
            margin-top: 20px;
            color: #3498db;
            text-decoration: none;
            font-weight: bold;
        }
        .back-link:hover {
            text-decoration: underline;
        }
        ul {
            list-style-type: none;
            padding: 0;
        }
        li {
            margin-bottom: 10px;
        }
    </style>
</head>
<body>
    <div class="logo">
        <img src="image/kanizsay.png" alt="Kanizsay logo">
    </div>

    <h1>Összes Kártya Igénylés</h1>

    <div class="section">
        <table>
            <tr>
                <th>Név</th>
                <th>Osztály</th>
                <th>Igénylés Dátuma</th>
                <th>Státusz</th>
            </tr>
            <?php while ($row = $osszes_igenyles->fetch_assoc()): ?>
            <tr>
                <td><?= htmlspecialchars($row['nev']) ?></td>
                <td><?= htmlspecialchars($row['osztaly']) ?></td>
                <td><?= htmlspecialchars($row['igenyles_datum']) ?></td>
                <td><?= htmlspecialchars($row['statusz']) ?></td>
            </tr>
            <?php endwhile; ?>
        </table>
    </div>

    <div class="section">
        <h2>Státusz magyarázatok</h2>
        <ul>
            <?php foreach ($statusz_leirasok as $statusz => $leiras): ?>
                <li><strong><?= htmlspecialchars($statusz) ?>:</strong> <?= htmlspecialchars($leiras) ?></li>
            <?php endforeach; ?>
        </ul>
    </div>

    <a href="admin.php" class="back-link">Vissza az admin felületre</a>
</body>
</html>