<?php
require_once 'config.php';
require_once 'functions.php';

session_start();
if (!isset($_SESSION['admin'])) {
    header("Location: admin.php");
    exit();
}

$message = '';
$sikeresek = 0;
$hibak = [];

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_FILES['csv_file'])) {
        $file = $_FILES['csv_file'];
        
        if ($file['error'] == UPLOAD_ERR_OK && (
            $file['type'] == 'text/csv' ||
            $file['type'] == 'application/vnd.ms-excel' ||
            $file['type'] == 'application/octet-stream'
        )) {
            $handle = fopen($file['tmp_name'], 'r');
            
            if ($handle !== FALSE) {
                // Skip BOM if present
                fgets($handle, 4) === "\xEF\xBB\xBF" ? rewind($handle) : fseek($handle, 0);
                
                while (($data = fgetcsv($handle, 1000, ";")) !== FALSE) {
                    // Trim whitespace from each field
                    $data = array_map('trim', $data);
                    
                    if (count($data) == 3 && !empty($data[0]) && !empty($data[1]) && !empty($data[2])) {
                        $om_azonosito = $data[0];
                        $nev = $data[1];
                        $osztaly = $data[2];
                        
                        if (preg_match('/^\d{11}$/', $om_azonosito)) {
                            $stmt = $db->prepare("SELECT id FROM diakok WHERE om_azonosito = ?");
                            $stmt->bind_param("s", $om_azonosito);
                            $stmt->execute();
                            $result = $stmt->get_result();
                            
                            if ($result->num_rows == 0) {
                                $stmt = $db->prepare("INSERT INTO diakok (om_azonosito, nev, osztaly) VALUES (?, ?, ?)");
                                $stmt->bind_param("sss", $om_azonosito, $nev, $osztaly);
                                
                                if ($stmt->execute()) {
                                    $sikeresek++;
                                } else {
                                    $hibak[] = "Hiba a diák felvétele során: $nev ($om_azonosito)";
                                }
                            } else {
                                $hibak[] = "Az OM azonosító már létezik: $om_azonosito";
                            }
                        } else {
                            $hibak[] = "Érvénytelen OM azonosító formátum: $om_azonosito, $nev, $osztaly";
                        }
                    } elseif (!empty(implode('', $data))) {
                        $hibak[] = "Hibás CSV sor: " . implode("; ", $data);
                    }
                }
                fclose($handle);
                
                $message = "Feltöltés kész. Sikeresen felvett diákok: $sikeresek";
            } else {
                $message = "Hiba a fájl megnyitása során.";
            }
        } else {
            $message = "Hiba a fájl feltöltése során. Kérjük, ellenőrizze, hogy CSV fájlt töltött-e fel.";
        }
    }
}
?>

<!DOCTYPE html>
<html lang="hu">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Diákok tömeges felvétele</title>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;700&display=swap" rel="stylesheet">
    <style>
        body { font-family: 'Roboto', sans-serif; max-width: 800px; margin: 0 auto; padding: 20px; }
        .logo { text-align: center; margin-bottom: 20px; }
        .logo img { max-width: 150px; height: auto; }
        h1 { color: #2c3e50; text-align: center; }
        form { background-color: #f0f0f0; padding: 20px; border-radius: 5px; margin-bottom: 20px; }
        input[type="file"], input[type="submit"] { margin: 10px 0; }
        .uzenet { background-color: #e0e0e0; padding: 10px; margin-top: 20px; border-radius: 5px; }
        .hiba { color: red; }
        .back-link { display: block; text-align: center; margin-top: 20px; }
    </style>
</head>
<body>
    <div class="logo">
        <img src="image/kanizsay.png" alt="Kanizsay logo">
    </div>
    <h1>Diákok tömeges felvétele CSV fájlból</h1>

    <form method="post" enctype="multipart/form-data">
        <p>Válassza ki a CSV fájlt (formátum: OM azonosító;Név;Osztály):</p>
        <input type="file" name="csv_file" accept=".csv" required>
        <input type="submit" value="Fájl feltöltése">
    </form>

    <?php if ($message): ?>
        <div class="uzenet"><?= htmlspecialchars($message) ?></div>
    <?php endif; ?>

    <?php if (!empty($hibak)): ?>
        <h2>Hibák:</h2>
        <ul>
            <?php foreach ($hibak as $hiba): ?>
                <li class="hiba"><?= htmlspecialchars($hiba) ?></li>
            <?php endforeach; ?>
        </ul>
    <?php endif; ?>

    <a href="admin.php" class="back-link">Vissza az admin felületre</a>
</body>
</html>